@@ -12,7 +12,7 @@ from six.moves.urllib.parse import urlparse, urlunparse
 from flask import url_for, request
 from werkzeug import cached_property
 
-from .inputs import date_from_iso8601, datetime_from_iso8601, datetime_from_rfc822
+from .inputs import date_from_iso8601, datetime_from_iso8601, datetime_from_rfc822, boolean
 from .errors import RestError
 from .marshalling import marshal
 from .utils import camel_to_dash, not_none
@@ -227,11 +227,13 @@ class Nested(Raw):
         if self.as_list:
             schema['type'] = 'array'
             schema['items'] = {'$ref': ref}
+        elif any(schema.values()):
+            # There is already some properties in the schema
+            allOf = schema.get('allOf', [])
+            allOf.append({'$ref': ref})
+            schema['allOf'] = allOf
         else:
             schema['$ref'] = ref
-            # if not self.allow_null and not self.readonly:
-            #     schema['required'] = True
-
         return schema
 
     def clone(self, mask=None):
@@ -377,7 +379,8 @@ class String(StringMixin, Raw):
     def schema(self):
         enum = self._v('enum')
         schema = super(String, self).schema()
-        schema.update(enum=enum)
+        if enum:
+            schema.update(enum=enum)
         if enum and schema['example'] is None:
             schema['example'] = enum[0]
         return schema
@@ -452,7 +455,7 @@ class Boolean(Raw):
     __schema_type__ = 'boolean'
 
     def format(self, value):
-        return bool(value)
+        return boolean(value)
 
 
 class DateTime(MinMaxMixin, Raw):
